from apadata.modules.evaluators.linguistical_evaluator_module import (
    LinguisticalEvaluatorModule,
)
from apadata.pipelines.pipeline_context import PipelineContext


def test_linguistical_evaluator_module():
    payload = {
        "keyword": "Consulting",
        "language": "en",
    }
    context = PipelineContext(payload=payload)
    module = LinguisticalEvaluatorModule()
    module.run(context)
    result = round(context.search_field("linguistical_score"), 4)
    assert result == 0.8333
